#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_tunnels(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def nsx_controller_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        nsx_controller = ET.SubElement(config, "nsx-controller", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name = ET.SubElement(nsx_controller, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def nsx_controller_connection_addr_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        nsx_controller = ET.SubElement(config, "nsx-controller", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(nsx_controller, "name")
        name_key.text = kwargs.pop('name')
        connection_addr = ET.SubElement(nsx_controller, "connection-addr")
        address = ET.SubElement(connection_addr, "address")
        address.text = kwargs.pop('address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def nsx_controller_connection_addr_port(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        nsx_controller = ET.SubElement(config, "nsx-controller", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(nsx_controller, "name")
        name_key.text = kwargs.pop('name')
        connection_addr = ET.SubElement(nsx_controller, "connection-addr")
        port = ET.SubElement(connection_addr, "port")
        port.text = kwargs.pop('port')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def nsx_controller_connection_addr_method(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        nsx_controller = ET.SubElement(config, "nsx-controller", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(nsx_controller, "name")
        name_key.text = kwargs.pop('name')
        connection_addr = ET.SubElement(nsx_controller, "connection-addr")
        method = ET.SubElement(connection_addr, "method")
        method.text = kwargs.pop('method')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def nsx_controller_reconnect_interval(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        nsx_controller = ET.SubElement(config, "nsx-controller", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(nsx_controller, "name")
        name_key.text = kwargs.pop('name')
        reconnect_interval = ET.SubElement(nsx_controller, "reconnect-interval")
        reconnect_interval.text = kwargs.pop('reconnect_interval')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def nsx_controller_activate(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        nsx_controller = ET.SubElement(config, "nsx-controller", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(nsx_controller, "name")
        name_key.text = kwargs.pop('name')
        activate = ET.SubElement(nsx_controller, "activate")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name = ET.SubElement(overlay_gateway, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_gw_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        gw_type = ET.SubElement(overlay_gateway, "gw-type")
        gw_type.text = kwargs.pop('gw_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_ip_interface_ve_ve_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        ip = ET.SubElement(overlay_gateway, "ip")
        interface = ET.SubElement(ip, "interface")
        ve = ET.SubElement(interface, "ve")
        ve_id = ET.SubElement(ve, "ve-id")
        ve_id.text = kwargs.pop('ve_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_ip_interface_ve_vrrp_extended_group(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        ip = ET.SubElement(overlay_gateway, "ip")
        interface = ET.SubElement(ip, "interface")
        ve = ET.SubElement(interface, "ve")
        vrrp_extended_group = ET.SubElement(ve, "vrrp-extended-group")
        vrrp_extended_group.text = kwargs.pop('vrrp_extended_group')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_ip_interface_loopback_loopback_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        ip = ET.SubElement(overlay_gateway, "ip")
        interface = ET.SubElement(ip, "interface")
        loopback = ET.SubElement(interface, "loopback")
        loopback_id = ET.SubElement(loopback, "loopback-id")
        loopback_id.text = kwargs.pop('loopback_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_attach_rbridge_id_rb_add(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        attach = ET.SubElement(overlay_gateway, "attach")
        rbridge_id = ET.SubElement(attach, "rbridge-id")
        rb_add = ET.SubElement(rbridge_id, "rb-add")
        rb_add.text = kwargs.pop('rb_add')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_attach_rbridge_id_rb_remove(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        attach = ET.SubElement(overlay_gateway, "attach")
        rbridge_id = ET.SubElement(attach, "rbridge-id")
        rb_remove = ET.SubElement(rbridge_id, "rb-remove")
        rb_remove.text = kwargs.pop('rb_remove')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_attach_vlan_vid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        attach = ET.SubElement(overlay_gateway, "attach")
        vlan = ET.SubElement(attach, "vlan")
        mac_key = ET.SubElement(vlan, "mac")
        mac_key.text = kwargs.pop('mac')
        vid = ET.SubElement(vlan, "vid")
        vid.text = kwargs.pop('vid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_attach_vlan_mac(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        attach = ET.SubElement(overlay_gateway, "attach")
        vlan = ET.SubElement(attach, "vlan")
        vid_key = ET.SubElement(vlan, "vid")
        vid_key.text = kwargs.pop('vid')
        mac = ET.SubElement(vlan, "mac")
        mac.text = kwargs.pop('mac')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_map_vlan_vni_mapping_vid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        map = ET.SubElement(overlay_gateway, "map")
        vlan_vni_mapping = ET.SubElement(map, "vlan-vni-mapping")
        vid = ET.SubElement(vlan_vni_mapping, "vid")
        vid.text = kwargs.pop('vid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_map_vlan_vni_mapping_vni(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        map = ET.SubElement(overlay_gateway, "map")
        vlan_vni_mapping = ET.SubElement(map, "vlan-vni-mapping")
        vid_key = ET.SubElement(vlan_vni_mapping, "vid")
        vid_key.text = kwargs.pop('vid')
        vni = ET.SubElement(vlan_vni_mapping, "vni")
        vni.text = kwargs.pop('vni')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_map_vlan_vni_auto(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        map = ET.SubElement(overlay_gateway, "map")
        vlan = ET.SubElement(map, "vlan")
        vni = ET.SubElement(vlan, "vni")
        auto = ET.SubElement(vni, "auto")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_site_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        site = ET.SubElement(overlay_gateway, "site")
        name = ET.SubElement(site, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_site_tunnel_dst_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        site = ET.SubElement(overlay_gateway, "site")
        name_key = ET.SubElement(site, "name")
        name_key.text = kwargs.pop('name')
        tunnel_dst = ET.SubElement(site, "tunnel-dst")
        address = ET.SubElement(tunnel_dst, "address")
        address.text = kwargs.pop('address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_site_extend_vlan_add(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        site = ET.SubElement(overlay_gateway, "site")
        name_key = ET.SubElement(site, "name")
        name_key.text = kwargs.pop('name')
        extend = ET.SubElement(site, "extend")
        vlan = ET.SubElement(extend, "vlan")
        add = ET.SubElement(vlan, "add")
        add.text = kwargs.pop('add')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_site_extend_vlan_remove(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        site = ET.SubElement(overlay_gateway, "site")
        name_key = ET.SubElement(site, "name")
        name_key.text = kwargs.pop('name')
        extend = ET.SubElement(site, "extend")
        vlan = ET.SubElement(extend, "vlan")
        remove = ET.SubElement(vlan, "remove")
        remove.text = kwargs.pop('remove')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_site_shutdown(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        site = ET.SubElement(overlay_gateway, "site")
        name_key = ET.SubElement(site, "name")
        name_key.text = kwargs.pop('name')
        shutdown = ET.SubElement(site, "shutdown")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_enable_statistics_stats_direction(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        enable = ET.SubElement(overlay_gateway, "enable")
        statistics = ET.SubElement(enable, "statistics")
        stats_direction = ET.SubElement(statistics, "stats-direction")
        stats_direction.text = kwargs.pop('stats_direction')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_enable_statistics_vlan_action(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        enable = ET.SubElement(overlay_gateway, "enable")
        statistics = ET.SubElement(enable, "statistics")
        vlan_action = ET.SubElement(statistics, "vlan-action")
        vlan_action.text = kwargs.pop('vlan_action')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_enable_statistics_vlan_list(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        enable = ET.SubElement(overlay_gateway, "enable")
        statistics = ET.SubElement(enable, "statistics")
        vlan_list = ET.SubElement(statistics, "vlan-list")
        vlan_list.text = kwargs.pop('vlan_list')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_monitor_session(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        monitor = ET.SubElement(overlay_gateway, "monitor")
        session = ET.SubElement(monitor, "session")
        session.text = kwargs.pop('session')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_monitor_direction(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        monitor = ET.SubElement(overlay_gateway, "monitor")
        session_key = ET.SubElement(monitor, "session")
        session_key.text = kwargs.pop('session')
        direction = ET.SubElement(monitor, "direction")
        direction.text = kwargs.pop('direction')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_monitor_remote_endpoint(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        monitor = ET.SubElement(overlay_gateway, "monitor")
        session_key = ET.SubElement(monitor, "session")
        session_key.text = kwargs.pop('session')
        remote_endpoint = ET.SubElement(monitor, "remote-endpoint")
        remote_endpoint.text = kwargs.pop('remote_endpoint')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_monitor_vlan_leaf(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        monitor = ET.SubElement(overlay_gateway, "monitor")
        session_key = ET.SubElement(monitor, "session")
        session_key.text = kwargs.pop('session')
        vlan_leaf = ET.SubElement(monitor, "vlan-leaf")
        vlan_leaf.text = kwargs.pop('vlan_leaf')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_monitor_vlan_add_remove(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        monitor = ET.SubElement(overlay_gateway, "monitor")
        session_key = ET.SubElement(monitor, "session")
        session_key.text = kwargs.pop('session')
        vlan_add_remove = ET.SubElement(monitor, "vlan-add-remove")
        vlan_add_remove.text = kwargs.pop('vlan_add_remove')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_monitor_vlan_range(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        monitor = ET.SubElement(overlay_gateway, "monitor")
        session_key = ET.SubElement(monitor, "session")
        session_key.text = kwargs.pop('session')
        vlan_range = ET.SubElement(monitor, "vlan-range")
        vlan_range.text = kwargs.pop('vlan_range')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_sflow_sflow_profile_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        sflow = ET.SubElement(overlay_gateway, "sflow")
        sflow_profile_name = ET.SubElement(sflow, "sflow-profile-name")
        sflow_profile_name.text = kwargs.pop('sflow_profile_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_sflow_sflow_remote_endpoint(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        sflow = ET.SubElement(overlay_gateway, "sflow")
        sflow_profile_name_key = ET.SubElement(sflow, "sflow-profile-name")
        sflow_profile_name_key.text = kwargs.pop('sflow_profile_name')
        sflow_remote_endpoint = ET.SubElement(sflow, "sflow-remote-endpoint")
        sflow_remote_endpoint.text = kwargs.pop('sflow_remote_endpoint')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_sflow_sflow_vlan_action(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        sflow = ET.SubElement(overlay_gateway, "sflow")
        sflow_profile_name_key = ET.SubElement(sflow, "sflow-profile-name")
        sflow_profile_name_key.text = kwargs.pop('sflow_profile_name')
        sflow_vlan_action = ET.SubElement(sflow, "sflow-vlan-action")
        sflow_vlan_action.text = kwargs.pop('sflow_vlan_action')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_sflow_sflow_vlan_range(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        sflow = ET.SubElement(overlay_gateway, "sflow")
        sflow_profile_name_key = ET.SubElement(sflow, "sflow-profile-name")
        sflow_profile_name_key.text = kwargs.pop('sflow_profile_name')
        sflow_vlan_range = ET.SubElement(sflow, "sflow-vlan-range")
        sflow_vlan_range.text = kwargs.pop('sflow_vlan_range')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_access_lists_mac_in_cg_mac_acl_in_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        access_lists = ET.SubElement(overlay_gateway, "access-lists")
        mac = ET.SubElement(access_lists, "mac")
        in_cg = ET.SubElement(mac, "in")
        mac_acl_in_name = ET.SubElement(in_cg, "mac-acl-in-name")
        mac_acl_in_name.text = kwargs.pop('mac_acl_in_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_access_lists_mac_in_cg_mac_acl_in_dir(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        access_lists = ET.SubElement(overlay_gateway, "access-lists")
        mac = ET.SubElement(access_lists, "mac")
        in_cg = ET.SubElement(mac, "in")
        mac_acl_in_dir = ET.SubElement(in_cg, "mac-acl-in-dir")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_access_lists_mac_out_mac_acl_out_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        access_lists = ET.SubElement(overlay_gateway, "access-lists")
        mac = ET.SubElement(access_lists, "mac")
        out = ET.SubElement(mac, "out")
        mac_acl_out_name = ET.SubElement(out, "mac-acl-out-name")
        mac_acl_out_name.text = kwargs.pop('mac_acl_out_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_access_lists_mac_out_mac_acl_out_dir(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        access_lists = ET.SubElement(overlay_gateway, "access-lists")
        mac = ET.SubElement(access_lists, "mac")
        out = ET.SubElement(mac, "out")
        mac_acl_out_dir = ET.SubElement(out, "mac-acl-out-dir")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_access_lists_ipv4_in_cg_ipv4_acl_in_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        access_lists = ET.SubElement(overlay_gateway, "access-lists")
        ipv4 = ET.SubElement(access_lists, "ipv4")
        in_cg = ET.SubElement(ipv4, "in")
        ipv4_acl_in_name = ET.SubElement(in_cg, "ipv4-acl-in-name")
        ipv4_acl_in_name.text = kwargs.pop('ipv4_acl_in_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_access_lists_ipv4_in_cg_ipv4_acl_in_dir(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        access_lists = ET.SubElement(overlay_gateway, "access-lists")
        ipv4 = ET.SubElement(access_lists, "ipv4")
        in_cg = ET.SubElement(ipv4, "in")
        ipv4_acl_in_dir = ET.SubElement(in_cg, "ipv4-acl-in-dir")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_access_lists_ipv4_out_ipv4_acl_out_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        access_lists = ET.SubElement(overlay_gateway, "access-lists")
        ipv4 = ET.SubElement(access_lists, "ipv4")
        out = ET.SubElement(ipv4, "out")
        ipv4_acl_out_name = ET.SubElement(out, "ipv4-acl-out-name")
        ipv4_acl_out_name.text = kwargs.pop('ipv4_acl_out_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_access_lists_ipv4_out_ipv4_acl_out_dir(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        access_lists = ET.SubElement(overlay_gateway, "access-lists")
        ipv4 = ET.SubElement(access_lists, "ipv4")
        out = ET.SubElement(ipv4, "out")
        ipv4_acl_out_dir = ET.SubElement(out, "ipv4-acl-out-dir")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_access_lists_ipv6_in_cg_ipv6_acl_in_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        access_lists = ET.SubElement(overlay_gateway, "access-lists")
        ipv6 = ET.SubElement(access_lists, "ipv6")
        in_cg = ET.SubElement(ipv6, "in")
        ipv6_acl_in_name = ET.SubElement(in_cg, "ipv6-acl-in-name")
        ipv6_acl_in_name.text = kwargs.pop('ipv6_acl_in_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_access_lists_ipv6_in_cg_ipv6_acl_in_dir(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        access_lists = ET.SubElement(overlay_gateway, "access-lists")
        ipv6 = ET.SubElement(access_lists, "ipv6")
        in_cg = ET.SubElement(ipv6, "in")
        ipv6_acl_in_dir = ET.SubElement(in_cg, "ipv6-acl-in-dir")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_access_lists_ipv6_out_ipv6_acl_out_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        access_lists = ET.SubElement(overlay_gateway, "access-lists")
        ipv6 = ET.SubElement(access_lists, "ipv6")
        out = ET.SubElement(ipv6, "out")
        ipv6_acl_out_name = ET.SubElement(out, "ipv6-acl-out-name")
        ipv6_acl_out_name.text = kwargs.pop('ipv6_acl_out_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_access_lists_ipv6_out_ipv6_acl_out_dir(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        access_lists = ET.SubElement(overlay_gateway, "access-lists")
        ipv6 = ET.SubElement(access_lists, "ipv6")
        out = ET.SubElement(ipv6, "out")
        ipv6_acl_out_dir = ET.SubElement(out, "ipv6-acl-out-dir")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_activate(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        activate = ET.SubElement(overlay_gateway, "activate")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def nsx_controller_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        nsx_controller = ET.SubElement(config, "nsx-controller", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name = ET.SubElement(nsx_controller, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def nsx_controller_connection_addr_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        nsx_controller = ET.SubElement(config, "nsx-controller", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(nsx_controller, "name")
        name_key.text = kwargs.pop('name')
        connection_addr = ET.SubElement(nsx_controller, "connection-addr")
        address = ET.SubElement(connection_addr, "address")
        address.text = kwargs.pop('address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def nsx_controller_connection_addr_port(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        nsx_controller = ET.SubElement(config, "nsx-controller", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(nsx_controller, "name")
        name_key.text = kwargs.pop('name')
        connection_addr = ET.SubElement(nsx_controller, "connection-addr")
        port = ET.SubElement(connection_addr, "port")
        port.text = kwargs.pop('port')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def nsx_controller_connection_addr_method(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        nsx_controller = ET.SubElement(config, "nsx-controller", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(nsx_controller, "name")
        name_key.text = kwargs.pop('name')
        connection_addr = ET.SubElement(nsx_controller, "connection-addr")
        method = ET.SubElement(connection_addr, "method")
        method.text = kwargs.pop('method')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def nsx_controller_reconnect_interval(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        nsx_controller = ET.SubElement(config, "nsx-controller", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(nsx_controller, "name")
        name_key.text = kwargs.pop('name')
        reconnect_interval = ET.SubElement(nsx_controller, "reconnect-interval")
        reconnect_interval.text = kwargs.pop('reconnect_interval')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def nsx_controller_activate(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        nsx_controller = ET.SubElement(config, "nsx-controller", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(nsx_controller, "name")
        name_key.text = kwargs.pop('name')
        activate = ET.SubElement(nsx_controller, "activate")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name = ET.SubElement(overlay_gateway, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_gw_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        gw_type = ET.SubElement(overlay_gateway, "gw-type")
        gw_type.text = kwargs.pop('gw_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_ip_interface_ve_ve_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        ip = ET.SubElement(overlay_gateway, "ip")
        interface = ET.SubElement(ip, "interface")
        ve = ET.SubElement(interface, "ve")
        ve_id = ET.SubElement(ve, "ve-id")
        ve_id.text = kwargs.pop('ve_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_ip_interface_ve_vrrp_extended_group(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        ip = ET.SubElement(overlay_gateway, "ip")
        interface = ET.SubElement(ip, "interface")
        ve = ET.SubElement(interface, "ve")
        vrrp_extended_group = ET.SubElement(ve, "vrrp-extended-group")
        vrrp_extended_group.text = kwargs.pop('vrrp_extended_group')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_ip_interface_loopback_loopback_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        ip = ET.SubElement(overlay_gateway, "ip")
        interface = ET.SubElement(ip, "interface")
        loopback = ET.SubElement(interface, "loopback")
        loopback_id = ET.SubElement(loopback, "loopback-id")
        loopback_id.text = kwargs.pop('loopback_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_attach_rbridge_id_rb_add(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        attach = ET.SubElement(overlay_gateway, "attach")
        rbridge_id = ET.SubElement(attach, "rbridge-id")
        rb_add = ET.SubElement(rbridge_id, "rb-add")
        rb_add.text = kwargs.pop('rb_add')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_attach_rbridge_id_rb_remove(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        attach = ET.SubElement(overlay_gateway, "attach")
        rbridge_id = ET.SubElement(attach, "rbridge-id")
        rb_remove = ET.SubElement(rbridge_id, "rb-remove")
        rb_remove.text = kwargs.pop('rb_remove')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_attach_vlan_vid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        attach = ET.SubElement(overlay_gateway, "attach")
        vlan = ET.SubElement(attach, "vlan")
        mac_key = ET.SubElement(vlan, "mac")
        mac_key.text = kwargs.pop('mac')
        vid = ET.SubElement(vlan, "vid")
        vid.text = kwargs.pop('vid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_attach_vlan_mac(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        attach = ET.SubElement(overlay_gateway, "attach")
        vlan = ET.SubElement(attach, "vlan")
        vid_key = ET.SubElement(vlan, "vid")
        vid_key.text = kwargs.pop('vid')
        mac = ET.SubElement(vlan, "mac")
        mac.text = kwargs.pop('mac')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_map_vlan_vni_mapping_vid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        map = ET.SubElement(overlay_gateway, "map")
        vlan_vni_mapping = ET.SubElement(map, "vlan-vni-mapping")
        vid = ET.SubElement(vlan_vni_mapping, "vid")
        vid.text = kwargs.pop('vid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_map_vlan_vni_mapping_vni(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        map = ET.SubElement(overlay_gateway, "map")
        vlan_vni_mapping = ET.SubElement(map, "vlan-vni-mapping")
        vid_key = ET.SubElement(vlan_vni_mapping, "vid")
        vid_key.text = kwargs.pop('vid')
        vni = ET.SubElement(vlan_vni_mapping, "vni")
        vni.text = kwargs.pop('vni')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_map_vlan_vni_auto(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        map = ET.SubElement(overlay_gateway, "map")
        vlan = ET.SubElement(map, "vlan")
        vni = ET.SubElement(vlan, "vni")
        auto = ET.SubElement(vni, "auto")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_site_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        site = ET.SubElement(overlay_gateway, "site")
        name = ET.SubElement(site, "name")
        name.text = kwargs.pop('name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_site_tunnel_dst_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        site = ET.SubElement(overlay_gateway, "site")
        name_key = ET.SubElement(site, "name")
        name_key.text = kwargs.pop('name')
        tunnel_dst = ET.SubElement(site, "tunnel-dst")
        address = ET.SubElement(tunnel_dst, "address")
        address.text = kwargs.pop('address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_site_extend_vlan_add(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        site = ET.SubElement(overlay_gateway, "site")
        name_key = ET.SubElement(site, "name")
        name_key.text = kwargs.pop('name')
        extend = ET.SubElement(site, "extend")
        vlan = ET.SubElement(extend, "vlan")
        add = ET.SubElement(vlan, "add")
        add.text = kwargs.pop('add')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_site_extend_vlan_remove(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        site = ET.SubElement(overlay_gateway, "site")
        name_key = ET.SubElement(site, "name")
        name_key.text = kwargs.pop('name')
        extend = ET.SubElement(site, "extend")
        vlan = ET.SubElement(extend, "vlan")
        remove = ET.SubElement(vlan, "remove")
        remove.text = kwargs.pop('remove')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_site_shutdown(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        site = ET.SubElement(overlay_gateway, "site")
        name_key = ET.SubElement(site, "name")
        name_key.text = kwargs.pop('name')
        shutdown = ET.SubElement(site, "shutdown")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_enable_statistics_stats_direction(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        enable = ET.SubElement(overlay_gateway, "enable")
        statistics = ET.SubElement(enable, "statistics")
        stats_direction = ET.SubElement(statistics, "stats-direction")
        stats_direction.text = kwargs.pop('stats_direction')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_enable_statistics_vlan_action(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        enable = ET.SubElement(overlay_gateway, "enable")
        statistics = ET.SubElement(enable, "statistics")
        vlan_action = ET.SubElement(statistics, "vlan-action")
        vlan_action.text = kwargs.pop('vlan_action')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_enable_statistics_vlan_list(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        enable = ET.SubElement(overlay_gateway, "enable")
        statistics = ET.SubElement(enable, "statistics")
        vlan_list = ET.SubElement(statistics, "vlan-list")
        vlan_list.text = kwargs.pop('vlan_list')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_monitor_session(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        monitor = ET.SubElement(overlay_gateway, "monitor")
        session = ET.SubElement(monitor, "session")
        session.text = kwargs.pop('session')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_monitor_direction(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        monitor = ET.SubElement(overlay_gateway, "monitor")
        session_key = ET.SubElement(monitor, "session")
        session_key.text = kwargs.pop('session')
        direction = ET.SubElement(monitor, "direction")
        direction.text = kwargs.pop('direction')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_monitor_remote_endpoint(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        monitor = ET.SubElement(overlay_gateway, "monitor")
        session_key = ET.SubElement(monitor, "session")
        session_key.text = kwargs.pop('session')
        remote_endpoint = ET.SubElement(monitor, "remote-endpoint")
        remote_endpoint.text = kwargs.pop('remote_endpoint')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_monitor_vlan_leaf(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        monitor = ET.SubElement(overlay_gateway, "monitor")
        session_key = ET.SubElement(monitor, "session")
        session_key.text = kwargs.pop('session')
        vlan_leaf = ET.SubElement(monitor, "vlan-leaf")
        vlan_leaf.text = kwargs.pop('vlan_leaf')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_monitor_vlan_add_remove(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        monitor = ET.SubElement(overlay_gateway, "monitor")
        session_key = ET.SubElement(monitor, "session")
        session_key.text = kwargs.pop('session')
        vlan_add_remove = ET.SubElement(monitor, "vlan-add-remove")
        vlan_add_remove.text = kwargs.pop('vlan_add_remove')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_monitor_vlan_range(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        monitor = ET.SubElement(overlay_gateway, "monitor")
        session_key = ET.SubElement(monitor, "session")
        session_key.text = kwargs.pop('session')
        vlan_range = ET.SubElement(monitor, "vlan-range")
        vlan_range.text = kwargs.pop('vlan_range')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_sflow_sflow_profile_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        sflow = ET.SubElement(overlay_gateway, "sflow")
        sflow_profile_name = ET.SubElement(sflow, "sflow-profile-name")
        sflow_profile_name.text = kwargs.pop('sflow_profile_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_sflow_sflow_remote_endpoint(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        sflow = ET.SubElement(overlay_gateway, "sflow")
        sflow_profile_name_key = ET.SubElement(sflow, "sflow-profile-name")
        sflow_profile_name_key.text = kwargs.pop('sflow_profile_name')
        sflow_remote_endpoint = ET.SubElement(sflow, "sflow-remote-endpoint")
        sflow_remote_endpoint.text = kwargs.pop('sflow_remote_endpoint')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_sflow_sflow_vlan_action(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        sflow = ET.SubElement(overlay_gateway, "sflow")
        sflow_profile_name_key = ET.SubElement(sflow, "sflow-profile-name")
        sflow_profile_name_key.text = kwargs.pop('sflow_profile_name')
        sflow_vlan_action = ET.SubElement(sflow, "sflow-vlan-action")
        sflow_vlan_action.text = kwargs.pop('sflow_vlan_action')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_sflow_sflow_vlan_range(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        sflow = ET.SubElement(overlay_gateway, "sflow")
        sflow_profile_name_key = ET.SubElement(sflow, "sflow-profile-name")
        sflow_profile_name_key.text = kwargs.pop('sflow_profile_name')
        sflow_vlan_range = ET.SubElement(sflow, "sflow-vlan-range")
        sflow_vlan_range.text = kwargs.pop('sflow_vlan_range')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_access_lists_mac_in_cg_mac_acl_in_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        access_lists = ET.SubElement(overlay_gateway, "access-lists")
        mac = ET.SubElement(access_lists, "mac")
        in_cg = ET.SubElement(mac, "in")
        mac_acl_in_name = ET.SubElement(in_cg, "mac-acl-in-name")
        mac_acl_in_name.text = kwargs.pop('mac_acl_in_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_access_lists_mac_in_cg_mac_acl_in_dir(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        access_lists = ET.SubElement(overlay_gateway, "access-lists")
        mac = ET.SubElement(access_lists, "mac")
        in_cg = ET.SubElement(mac, "in")
        mac_acl_in_dir = ET.SubElement(in_cg, "mac-acl-in-dir")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_access_lists_mac_out_mac_acl_out_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        access_lists = ET.SubElement(overlay_gateway, "access-lists")
        mac = ET.SubElement(access_lists, "mac")
        out = ET.SubElement(mac, "out")
        mac_acl_out_name = ET.SubElement(out, "mac-acl-out-name")
        mac_acl_out_name.text = kwargs.pop('mac_acl_out_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_access_lists_mac_out_mac_acl_out_dir(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        access_lists = ET.SubElement(overlay_gateway, "access-lists")
        mac = ET.SubElement(access_lists, "mac")
        out = ET.SubElement(mac, "out")
        mac_acl_out_dir = ET.SubElement(out, "mac-acl-out-dir")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_access_lists_ipv4_in_cg_ipv4_acl_in_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        access_lists = ET.SubElement(overlay_gateway, "access-lists")
        ipv4 = ET.SubElement(access_lists, "ipv4")
        in_cg = ET.SubElement(ipv4, "in")
        ipv4_acl_in_name = ET.SubElement(in_cg, "ipv4-acl-in-name")
        ipv4_acl_in_name.text = kwargs.pop('ipv4_acl_in_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_access_lists_ipv4_in_cg_ipv4_acl_in_dir(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        access_lists = ET.SubElement(overlay_gateway, "access-lists")
        ipv4 = ET.SubElement(access_lists, "ipv4")
        in_cg = ET.SubElement(ipv4, "in")
        ipv4_acl_in_dir = ET.SubElement(in_cg, "ipv4-acl-in-dir")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_access_lists_ipv4_out_ipv4_acl_out_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        access_lists = ET.SubElement(overlay_gateway, "access-lists")
        ipv4 = ET.SubElement(access_lists, "ipv4")
        out = ET.SubElement(ipv4, "out")
        ipv4_acl_out_name = ET.SubElement(out, "ipv4-acl-out-name")
        ipv4_acl_out_name.text = kwargs.pop('ipv4_acl_out_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_access_lists_ipv4_out_ipv4_acl_out_dir(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        access_lists = ET.SubElement(overlay_gateway, "access-lists")
        ipv4 = ET.SubElement(access_lists, "ipv4")
        out = ET.SubElement(ipv4, "out")
        ipv4_acl_out_dir = ET.SubElement(out, "ipv4-acl-out-dir")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_access_lists_ipv6_in_cg_ipv6_acl_in_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        access_lists = ET.SubElement(overlay_gateway, "access-lists")
        ipv6 = ET.SubElement(access_lists, "ipv6")
        in_cg = ET.SubElement(ipv6, "in")
        ipv6_acl_in_name = ET.SubElement(in_cg, "ipv6-acl-in-name")
        ipv6_acl_in_name.text = kwargs.pop('ipv6_acl_in_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_access_lists_ipv6_in_cg_ipv6_acl_in_dir(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        access_lists = ET.SubElement(overlay_gateway, "access-lists")
        ipv6 = ET.SubElement(access_lists, "ipv6")
        in_cg = ET.SubElement(ipv6, "in")
        ipv6_acl_in_dir = ET.SubElement(in_cg, "ipv6-acl-in-dir")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_access_lists_ipv6_out_ipv6_acl_out_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        access_lists = ET.SubElement(overlay_gateway, "access-lists")
        ipv6 = ET.SubElement(access_lists, "ipv6")
        out = ET.SubElement(ipv6, "out")
        ipv6_acl_out_name = ET.SubElement(out, "ipv6-acl-out-name")
        ipv6_acl_out_name.text = kwargs.pop('ipv6_acl_out_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_access_lists_ipv6_out_ipv6_acl_out_dir(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        access_lists = ET.SubElement(overlay_gateway, "access-lists")
        ipv6 = ET.SubElement(access_lists, "ipv6")
        out = ET.SubElement(ipv6, "out")
        ipv6_acl_out_dir = ET.SubElement(out, "ipv6-acl-out-dir")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def overlay_gateway_activate(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        overlay_gateway = ET.SubElement(config, "overlay-gateway", xmlns="urn:brocade.com:mgmt:brocade-tunnels")
        name_key = ET.SubElement(overlay_gateway, "name")
        name_key.text = kwargs.pop('name')
        activate = ET.SubElement(overlay_gateway, "activate")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_ntp(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def show_ntp_input_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_ntp = ET.Element("show_ntp")
        config = show_ntp
        input = ET.SubElement(show_ntp, "input")
        rbridge_id = ET.SubElement(input, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_ntp_output_node_active_server_rbridge_id_out(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_ntp = ET.Element("show_ntp")
        config = show_ntp
        output = ET.SubElement(show_ntp, "output")
        node_active_server = ET.SubElement(output, "node-active-server")
        rbridge_id_out = ET.SubElement(node_active_server, "rbridge-id-out")
        rbridge_id_out.text = kwargs.pop('rbridge_id_out')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_ntp_output_node_active_server_ip4_6_or_local_ipv4_6_active_server(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_ntp = ET.Element("show_ntp")
        config = show_ntp
        output = ET.SubElement(show_ntp, "output")
        node_active_server = ET.SubElement(output, "node-active-server")
        ip4_6_or_local = ET.SubElement(node_active_server, "ip4-6-or-local")
        ipv4_6 = ET.SubElement(ip4_6_or_local, "ipv4-6")
        active_server = ET.SubElement(ipv4_6, "active-server")
        active_server.text = kwargs.pop('active_server')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_ntp_output_node_active_server_ip4_6_or_local_local_LOCL(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_ntp = ET.Element("show_ntp")
        config = show_ntp
        output = ET.SubElement(show_ntp, "output")
        node_active_server = ET.SubElement(output, "node-active-server")
        ip4_6_or_local = ET.SubElement(node_active_server, "ip4-6-or-local")
        local = ET.SubElement(ip4_6_or_local, "local")
        LOCL = ET.SubElement(local, "LOCL")
        LOCL.text = kwargs.pop('LOCL')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def ntp_server_ip(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        ntp = ET.SubElement(config, "ntp", xmlns="urn:brocade.com:mgmt:brocade-ntp")
        server = ET.SubElement(ntp, "server")
        ip = ET.SubElement(server, "ip")
        ip.text = kwargs.pop('ip')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def ntp_server_key(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        ntp = ET.SubElement(config, "ntp", xmlns="urn:brocade.com:mgmt:brocade-ntp")
        server = ET.SubElement(ntp, "server")
        ip_key = ET.SubElement(server, "ip")
        ip_key.text = kwargs.pop('ip')
        key = ET.SubElement(server, "key")
        key.text = kwargs.pop('key')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def ntp_authentication_key_keyid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        ntp = ET.SubElement(config, "ntp", xmlns="urn:brocade.com:mgmt:brocade-ntp")
        authentication_key = ET.SubElement(ntp, "authentication-key")
        keyid = ET.SubElement(authentication_key, "keyid")
        keyid.text = kwargs.pop('keyid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def ntp_authentication_key_encryption_type_md5_type_md5(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        ntp = ET.SubElement(config, "ntp", xmlns="urn:brocade.com:mgmt:brocade-ntp")
        authentication_key = ET.SubElement(ntp, "authentication-key")
        keyid_key = ET.SubElement(authentication_key, "keyid")
        keyid_key.text = kwargs.pop('keyid')
        encryption_type = ET.SubElement(authentication_key, "encryption-type")
        md5_type = ET.SubElement(encryption_type, "md5-type")
        md5 = ET.SubElement(md5_type, "md5")
        md5.text = kwargs.pop('md5')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def ntp_authentication_key_encryption_type_sha1_type_sha1(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        ntp = ET.SubElement(config, "ntp", xmlns="urn:brocade.com:mgmt:brocade-ntp")
        authentication_key = ET.SubElement(ntp, "authentication-key")
        keyid_key = ET.SubElement(authentication_key, "keyid")
        keyid_key.text = kwargs.pop('keyid')
        encryption_type = ET.SubElement(authentication_key, "encryption-type")
        sha1_type = ET.SubElement(encryption_type, "sha1-type")
        sha1 = ET.SubElement(sha1_type, "sha1")
        sha1.text = kwargs.pop('sha1')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def ntp_authentication_key_encryption_level(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        ntp = ET.SubElement(config, "ntp", xmlns="urn:brocade.com:mgmt:brocade-ntp")
        authentication_key = ET.SubElement(ntp, "authentication-key")
        keyid_key = ET.SubElement(authentication_key, "keyid")
        keyid_key.text = kwargs.pop('keyid')
        encryption_level = ET.SubElement(authentication_key, "encryption-level")
        encryption_level.text = kwargs.pop('encryption_level')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def ntp_source_ip(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        ntp = ET.SubElement(config, "ntp", xmlns="urn:brocade.com:mgmt:brocade-ntp")
        source_ip = ET.SubElement(ntp, "source-ip")
        source_ip.text = kwargs.pop('source_ip')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_ntp_input_rbridge_id(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_ntp = ET.Element("show_ntp")
        config = show_ntp
        input = ET.SubElement(show_ntp, "input")
        rbridge_id = ET.SubElement(input, "rbridge-id")
        rbridge_id.text = kwargs.pop('rbridge_id')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_ntp_output_node_active_server_rbridge_id_out(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_ntp = ET.Element("show_ntp")
        config = show_ntp
        output = ET.SubElement(show_ntp, "output")
        node_active_server = ET.SubElement(output, "node-active-server")
        rbridge_id_out = ET.SubElement(node_active_server, "rbridge-id-out")
        rbridge_id_out.text = kwargs.pop('rbridge_id_out')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_ntp_output_node_active_server_ip4_6_or_local_ipv4_6_active_server(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_ntp = ET.Element("show_ntp")
        config = show_ntp
        output = ET.SubElement(show_ntp, "output")
        node_active_server = ET.SubElement(output, "node-active-server")
        ip4_6_or_local = ET.SubElement(node_active_server, "ip4-6-or-local")
        ipv4_6 = ET.SubElement(ip4_6_or_local, "ipv4-6")
        active_server = ET.SubElement(ipv4_6, "active-server")
        active_server.text = kwargs.pop('active_server')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def show_ntp_output_node_active_server_ip4_6_or_local_local_LOCL(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        show_ntp = ET.Element("show_ntp")
        config = show_ntp
        output = ET.SubElement(show_ntp, "output")
        node_active_server = ET.SubElement(output, "node-active-server")
        ip4_6_or_local = ET.SubElement(node_active_server, "ip4-6-or-local")
        local = ET.SubElement(ip4_6_or_local, "local")
        LOCL = ET.SubElement(local, "LOCL")
        LOCL.text = kwargs.pop('LOCL')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def ntp_server_ip(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        ntp = ET.SubElement(config, "ntp", xmlns="urn:brocade.com:mgmt:brocade-ntp")
        server = ET.SubElement(ntp, "server")
        ip = ET.SubElement(server, "ip")
        ip.text = kwargs.pop('ip')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def ntp_server_key(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        ntp = ET.SubElement(config, "ntp", xmlns="urn:brocade.com:mgmt:brocade-ntp")
        server = ET.SubElement(ntp, "server")
        ip_key = ET.SubElement(server, "ip")
        ip_key.text = kwargs.pop('ip')
        key = ET.SubElement(server, "key")
        key.text = kwargs.pop('key')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def ntp_authentication_key_keyid(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        ntp = ET.SubElement(config, "ntp", xmlns="urn:brocade.com:mgmt:brocade-ntp")
        authentication_key = ET.SubElement(ntp, "authentication-key")
        keyid = ET.SubElement(authentication_key, "keyid")
        keyid.text = kwargs.pop('keyid')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def ntp_authentication_key_encryption_type_md5_type_md5(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        ntp = ET.SubElement(config, "ntp", xmlns="urn:brocade.com:mgmt:brocade-ntp")
        authentication_key = ET.SubElement(ntp, "authentication-key")
        keyid_key = ET.SubElement(authentication_key, "keyid")
        keyid_key.text = kwargs.pop('keyid')
        encryption_type = ET.SubElement(authentication_key, "encryption-type")
        md5_type = ET.SubElement(encryption_type, "md5-type")
        md5 = ET.SubElement(md5_type, "md5")
        md5.text = kwargs.pop('md5')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def ntp_authentication_key_encryption_type_sha1_type_sha1(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        ntp = ET.SubElement(config, "ntp", xmlns="urn:brocade.com:mgmt:brocade-ntp")
        authentication_key = ET.SubElement(ntp, "authentication-key")
        keyid_key = ET.SubElement(authentication_key, "keyid")
        keyid_key.text = kwargs.pop('keyid')
        encryption_type = ET.SubElement(authentication_key, "encryption-type")
        sha1_type = ET.SubElement(encryption_type, "sha1-type")
        sha1 = ET.SubElement(sha1_type, "sha1")
        sha1.text = kwargs.pop('sha1')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def ntp_authentication_key_encryption_level(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        ntp = ET.SubElement(config, "ntp", xmlns="urn:brocade.com:mgmt:brocade-ntp")
        authentication_key = ET.SubElement(ntp, "authentication-key")
        keyid_key = ET.SubElement(authentication_key, "keyid")
        keyid_key.text = kwargs.pop('keyid')
        encryption_level = ET.SubElement(authentication_key, "encryption-level")
        encryption_level.text = kwargs.pop('encryption_level')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def ntp_source_ip(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        ntp = ET.SubElement(config, "ntp", xmlns="urn:brocade.com:mgmt:brocade-ntp")
        source_ip = ET.SubElement(ntp, "source-ip")
        source_ip.text = kwargs.pop('source_ip')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


#!/usr/bin/env python
import xml.etree.ElementTree as ET


class brocade_arp(object):
    """Auto generated class.
    """
    def __init__(self, **kwargs):
        self._callback = kwargs.pop('callback')

            
    def hide_arp_holder_system_max_arp(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_arp_holder = ET.SubElement(config, "hide-arp-holder", xmlns="urn:brocade.com:mgmt:brocade-arp")
        system_max = ET.SubElement(hide_arp_holder, "system-max")
        arp = ET.SubElement(system_max, "arp")
        arp.text = kwargs.pop('arp')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_arp_holder_arp_entry_arp_ip_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_arp_holder = ET.SubElement(config, "hide-arp-holder", xmlns="urn:brocade.com:mgmt:brocade-arp")
        arp_entry = ET.SubElement(hide_arp_holder, "arp-entry")
        arp_ip_address = ET.SubElement(arp_entry, "arp-ip-address")
        arp_ip_address.text = kwargs.pop('arp_ip_address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_arp_holder_arp_entry_mac_address_value(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_arp_holder = ET.SubElement(config, "hide-arp-holder", xmlns="urn:brocade.com:mgmt:brocade-arp")
        arp_entry = ET.SubElement(hide_arp_holder, "arp-entry")
        arp_ip_address_key = ET.SubElement(arp_entry, "arp-ip-address")
        arp_ip_address_key.text = kwargs.pop('arp_ip_address')
        mac_address_value = ET.SubElement(arp_entry, "mac-address-value")
        mac_address_value.text = kwargs.pop('mac_address_value')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_arp_holder_arp_entry_interfacename(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_arp_holder = ET.SubElement(config, "hide-arp-holder", xmlns="urn:brocade.com:mgmt:brocade-arp")
        arp_entry = ET.SubElement(hide_arp_holder, "arp-entry")
        arp_ip_address_key = ET.SubElement(arp_entry, "arp-ip-address")
        arp_ip_address_key.text = kwargs.pop('arp_ip_address')
        interfacename = ET.SubElement(arp_entry, "interfacename")
        interfacename.text = kwargs.pop('interfacename')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_arp_holder_arp_entry_interfacetype_GigabitEthernet_GigabitEthernet(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_arp_holder = ET.SubElement(config, "hide-arp-holder", xmlns="urn:brocade.com:mgmt:brocade-arp")
        arp_entry = ET.SubElement(hide_arp_holder, "arp-entry")
        arp_ip_address_key = ET.SubElement(arp_entry, "arp-ip-address")
        arp_ip_address_key.text = kwargs.pop('arp_ip_address')
        interfacetype = ET.SubElement(arp_entry, "interfacetype")
        GigabitEthernet = ET.SubElement(interfacetype, "GigabitEthernet")
        GigabitEthernet = ET.SubElement(GigabitEthernet, "GigabitEthernet")
        GigabitEthernet.text = kwargs.pop('GigabitEthernet')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_arp_holder_arp_entry_interfacetype_TenGigabitEthernet_TenGigabitEthernet(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_arp_holder = ET.SubElement(config, "hide-arp-holder", xmlns="urn:brocade.com:mgmt:brocade-arp")
        arp_entry = ET.SubElement(hide_arp_holder, "arp-entry")
        arp_ip_address_key = ET.SubElement(arp_entry, "arp-ip-address")
        arp_ip_address_key.text = kwargs.pop('arp_ip_address')
        interfacetype = ET.SubElement(arp_entry, "interfacetype")
        TenGigabitEthernet = ET.SubElement(interfacetype, "TenGigabitEthernet")
        TenGigabitEthernet = ET.SubElement(TenGigabitEthernet, "TenGigabitEthernet")
        TenGigabitEthernet.text = kwargs.pop('TenGigabitEthernet')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_arp_holder_arp_entry_interfacetype_FortyGigabitEthernet_FortyGigabitEthernet(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_arp_holder = ET.SubElement(config, "hide-arp-holder", xmlns="urn:brocade.com:mgmt:brocade-arp")
        arp_entry = ET.SubElement(hide_arp_holder, "arp-entry")
        arp_ip_address_key = ET.SubElement(arp_entry, "arp-ip-address")
        arp_ip_address_key.text = kwargs.pop('arp_ip_address')
        interfacetype = ET.SubElement(arp_entry, "interfacetype")
        FortyGigabitEthernet = ET.SubElement(interfacetype, "FortyGigabitEthernet")
        FortyGigabitEthernet = ET.SubElement(FortyGigabitEthernet, "FortyGigabitEthernet")
        FortyGigabitEthernet.text = kwargs.pop('FortyGigabitEthernet')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_arp_holder_arp_entry_interfacetype_HundredGigabitEthernet_HundredGigabitEthernet(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_arp_holder = ET.SubElement(config, "hide-arp-holder", xmlns="urn:brocade.com:mgmt:brocade-arp")
        arp_entry = ET.SubElement(hide_arp_holder, "arp-entry")
        arp_ip_address_key = ET.SubElement(arp_entry, "arp-ip-address")
        arp_ip_address_key.text = kwargs.pop('arp_ip_address')
        interfacetype = ET.SubElement(arp_entry, "interfacetype")
        HundredGigabitEthernet = ET.SubElement(interfacetype, "HundredGigabitEthernet")
        HundredGigabitEthernet = ET.SubElement(HundredGigabitEthernet, "HundredGigabitEthernet")
        HundredGigabitEthernet.text = kwargs.pop('HundredGigabitEthernet')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_arp_holder_arp_entry_interfacetype_Ve_Ve(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_arp_holder = ET.SubElement(config, "hide-arp-holder", xmlns="urn:brocade.com:mgmt:brocade-arp")
        arp_entry = ET.SubElement(hide_arp_holder, "arp-entry")
        arp_ip_address_key = ET.SubElement(arp_entry, "arp-ip-address")
        arp_ip_address_key.text = kwargs.pop('arp_ip_address')
        interfacetype = ET.SubElement(arp_entry, "interfacetype")
        Ve = ET.SubElement(interfacetype, "Ve")
        Ve = ET.SubElement(Ve, "Ve")
        Ve.text = kwargs.pop('Ve')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_arp_input_input_type_interface_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_arp = ET.Element("get_arp")
        config = get_arp
        input = ET.SubElement(get_arp, "input")
        input_type = ET.SubElement(input, "input-type")
        interface = ET.SubElement(input_type, "interface")
        interface_type = ET.SubElement(interface, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_arp_input_input_type_interface_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_arp = ET.Element("get_arp")
        config = get_arp
        input = ET.SubElement(get_arp, "input")
        input_type = ET.SubElement(input, "input-type")
        interface = ET.SubElement(input_type, "interface")
        interface_name = ET.SubElement(interface, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_arp_input_input_type_dynamic_dynamic(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_arp = ET.Element("get_arp")
        config = get_arp
        input = ET.SubElement(get_arp, "input")
        input_type = ET.SubElement(input, "input-type")
        dynamic = ET.SubElement(input_type, "dynamic")
        dynamic = ET.SubElement(dynamic, "dynamic")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_arp_input_input_type_static_static(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_arp = ET.Element("get_arp")
        config = get_arp
        input = ET.SubElement(get_arp, "input")
        input_type = ET.SubElement(input, "input-type")
        static = ET.SubElement(input_type, "static")
        static = ET.SubElement(static, "static")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_arp_input_input_type_ip_ip_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_arp = ET.Element("get_arp")
        config = get_arp
        input = ET.SubElement(get_arp, "input")
        input_type = ET.SubElement(input, "input-type")
        ip = ET.SubElement(input_type, "ip")
        ip_address = ET.SubElement(ip, "ip-address")
        ip_address.text = kwargs.pop('ip_address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_arp_output_arp_entry_ip_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_arp = ET.Element("get_arp")
        config = get_arp
        output = ET.SubElement(get_arp, "output")
        arp_entry = ET.SubElement(output, "arp-entry")
        ip_address = ET.SubElement(arp_entry, "ip-address")
        ip_address.text = kwargs.pop('ip_address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_arp_output_arp_entry_mac_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_arp = ET.Element("get_arp")
        config = get_arp
        output = ET.SubElement(get_arp, "output")
        arp_entry = ET.SubElement(output, "arp-entry")
        ip_address_key = ET.SubElement(arp_entry, "ip-address")
        ip_address_key.text = kwargs.pop('ip_address')
        mac_address = ET.SubElement(arp_entry, "mac-address")
        mac_address.text = kwargs.pop('mac_address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_arp_output_arp_entry_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_arp = ET.Element("get_arp")
        config = get_arp
        output = ET.SubElement(get_arp, "output")
        arp_entry = ET.SubElement(output, "arp-entry")
        ip_address_key = ET.SubElement(arp_entry, "ip-address")
        ip_address_key.text = kwargs.pop('ip_address')
        interface_type = ET.SubElement(arp_entry, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_arp_output_arp_entry_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_arp = ET.Element("get_arp")
        config = get_arp
        output = ET.SubElement(get_arp, "output")
        arp_entry = ET.SubElement(output, "arp-entry")
        ip_address_key = ET.SubElement(arp_entry, "ip-address")
        ip_address_key.text = kwargs.pop('ip_address')
        interface_name = ET.SubElement(arp_entry, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_arp_output_arp_entry_is_resolved(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_arp = ET.Element("get_arp")
        config = get_arp
        output = ET.SubElement(get_arp, "output")
        arp_entry = ET.SubElement(output, "arp-entry")
        ip_address_key = ET.SubElement(arp_entry, "ip-address")
        ip_address_key.text = kwargs.pop('ip_address')
        is_resolved = ET.SubElement(arp_entry, "is-resolved")
        is_resolved.text = kwargs.pop('is_resolved')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_arp_output_arp_entry_age(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_arp = ET.Element("get_arp")
        config = get_arp
        output = ET.SubElement(get_arp, "output")
        arp_entry = ET.SubElement(output, "arp-entry")
        ip_address_key = ET.SubElement(arp_entry, "ip-address")
        ip_address_key.text = kwargs.pop('ip_address')
        age = ET.SubElement(arp_entry, "age")
        age.text = kwargs.pop('age')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_arp_output_arp_entry_entry_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_arp = ET.Element("get_arp")
        config = get_arp
        output = ET.SubElement(get_arp, "output")
        arp_entry = ET.SubElement(output, "arp-entry")
        ip_address_key = ET.SubElement(arp_entry, "ip-address")
        ip_address_key.text = kwargs.pop('ip_address')
        entry_type = ET.SubElement(arp_entry, "entry-type")
        entry_type.text = kwargs.pop('entry_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_arp_holder_system_max_arp(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_arp_holder = ET.SubElement(config, "hide-arp-holder", xmlns="urn:brocade.com:mgmt:brocade-arp")
        system_max = ET.SubElement(hide_arp_holder, "system-max")
        arp = ET.SubElement(system_max, "arp")
        arp.text = kwargs.pop('arp')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_arp_holder_arp_entry_arp_ip_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_arp_holder = ET.SubElement(config, "hide-arp-holder", xmlns="urn:brocade.com:mgmt:brocade-arp")
        arp_entry = ET.SubElement(hide_arp_holder, "arp-entry")
        arp_ip_address = ET.SubElement(arp_entry, "arp-ip-address")
        arp_ip_address.text = kwargs.pop('arp_ip_address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_arp_holder_arp_entry_mac_address_value(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_arp_holder = ET.SubElement(config, "hide-arp-holder", xmlns="urn:brocade.com:mgmt:brocade-arp")
        arp_entry = ET.SubElement(hide_arp_holder, "arp-entry")
        arp_ip_address_key = ET.SubElement(arp_entry, "arp-ip-address")
        arp_ip_address_key.text = kwargs.pop('arp_ip_address')
        mac_address_value = ET.SubElement(arp_entry, "mac-address-value")
        mac_address_value.text = kwargs.pop('mac_address_value')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_arp_holder_arp_entry_interfacename(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_arp_holder = ET.SubElement(config, "hide-arp-holder", xmlns="urn:brocade.com:mgmt:brocade-arp")
        arp_entry = ET.SubElement(hide_arp_holder, "arp-entry")
        arp_ip_address_key = ET.SubElement(arp_entry, "arp-ip-address")
        arp_ip_address_key.text = kwargs.pop('arp_ip_address')
        interfacename = ET.SubElement(arp_entry, "interfacename")
        interfacename.text = kwargs.pop('interfacename')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_arp_holder_arp_entry_interfacetype_GigabitEthernet_GigabitEthernet(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_arp_holder = ET.SubElement(config, "hide-arp-holder", xmlns="urn:brocade.com:mgmt:brocade-arp")
        arp_entry = ET.SubElement(hide_arp_holder, "arp-entry")
        arp_ip_address_key = ET.SubElement(arp_entry, "arp-ip-address")
        arp_ip_address_key.text = kwargs.pop('arp_ip_address')
        interfacetype = ET.SubElement(arp_entry, "interfacetype")
        GigabitEthernet = ET.SubElement(interfacetype, "GigabitEthernet")
        GigabitEthernet = ET.SubElement(GigabitEthernet, "GigabitEthernet")
        GigabitEthernet.text = kwargs.pop('GigabitEthernet')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_arp_holder_arp_entry_interfacetype_TenGigabitEthernet_TenGigabitEthernet(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_arp_holder = ET.SubElement(config, "hide-arp-holder", xmlns="urn:brocade.com:mgmt:brocade-arp")
        arp_entry = ET.SubElement(hide_arp_holder, "arp-entry")
        arp_ip_address_key = ET.SubElement(arp_entry, "arp-ip-address")
        arp_ip_address_key.text = kwargs.pop('arp_ip_address')
        interfacetype = ET.SubElement(arp_entry, "interfacetype")
        TenGigabitEthernet = ET.SubElement(interfacetype, "TenGigabitEthernet")
        TenGigabitEthernet = ET.SubElement(TenGigabitEthernet, "TenGigabitEthernet")
        TenGigabitEthernet.text = kwargs.pop('TenGigabitEthernet')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_arp_holder_arp_entry_interfacetype_FortyGigabitEthernet_FortyGigabitEthernet(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_arp_holder = ET.SubElement(config, "hide-arp-holder", xmlns="urn:brocade.com:mgmt:brocade-arp")
        arp_entry = ET.SubElement(hide_arp_holder, "arp-entry")
        arp_ip_address_key = ET.SubElement(arp_entry, "arp-ip-address")
        arp_ip_address_key.text = kwargs.pop('arp_ip_address')
        interfacetype = ET.SubElement(arp_entry, "interfacetype")
        FortyGigabitEthernet = ET.SubElement(interfacetype, "FortyGigabitEthernet")
        FortyGigabitEthernet = ET.SubElement(FortyGigabitEthernet, "FortyGigabitEthernet")
        FortyGigabitEthernet.text = kwargs.pop('FortyGigabitEthernet')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_arp_holder_arp_entry_interfacetype_HundredGigabitEthernet_HundredGigabitEthernet(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_arp_holder = ET.SubElement(config, "hide-arp-holder", xmlns="urn:brocade.com:mgmt:brocade-arp")
        arp_entry = ET.SubElement(hide_arp_holder, "arp-entry")
        arp_ip_address_key = ET.SubElement(arp_entry, "arp-ip-address")
        arp_ip_address_key.text = kwargs.pop('arp_ip_address')
        interfacetype = ET.SubElement(arp_entry, "interfacetype")
        HundredGigabitEthernet = ET.SubElement(interfacetype, "HundredGigabitEthernet")
        HundredGigabitEthernet = ET.SubElement(HundredGigabitEthernet, "HundredGigabitEthernet")
        HundredGigabitEthernet.text = kwargs.pop('HundredGigabitEthernet')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def hide_arp_holder_arp_entry_interfacetype_Ve_Ve(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        hide_arp_holder = ET.SubElement(config, "hide-arp-holder", xmlns="urn:brocade.com:mgmt:brocade-arp")
        arp_entry = ET.SubElement(hide_arp_holder, "arp-entry")
        arp_ip_address_key = ET.SubElement(arp_entry, "arp-ip-address")
        arp_ip_address_key.text = kwargs.pop('arp_ip_address')
        interfacetype = ET.SubElement(arp_entry, "interfacetype")
        Ve = ET.SubElement(interfacetype, "Ve")
        Ve = ET.SubElement(Ve, "Ve")
        Ve.text = kwargs.pop('Ve')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_arp_input_input_type_interface_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_arp = ET.Element("get_arp")
        config = get_arp
        input = ET.SubElement(get_arp, "input")
        input_type = ET.SubElement(input, "input-type")
        interface = ET.SubElement(input_type, "interface")
        interface_type = ET.SubElement(interface, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_arp_input_input_type_interface_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_arp = ET.Element("get_arp")
        config = get_arp
        input = ET.SubElement(get_arp, "input")
        input_type = ET.SubElement(input, "input-type")
        interface = ET.SubElement(input_type, "interface")
        interface_name = ET.SubElement(interface, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_arp_input_input_type_dynamic_dynamic(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_arp = ET.Element("get_arp")
        config = get_arp
        input = ET.SubElement(get_arp, "input")
        input_type = ET.SubElement(input, "input-type")
        dynamic = ET.SubElement(input_type, "dynamic")
        dynamic = ET.SubElement(dynamic, "dynamic")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_arp_input_input_type_static_static(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_arp = ET.Element("get_arp")
        config = get_arp
        input = ET.SubElement(get_arp, "input")
        input_type = ET.SubElement(input, "input-type")
        static = ET.SubElement(input_type, "static")
        static = ET.SubElement(static, "static")

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_arp_input_input_type_ip_ip_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_arp = ET.Element("get_arp")
        config = get_arp
        input = ET.SubElement(get_arp, "input")
        input_type = ET.SubElement(input, "input-type")
        ip = ET.SubElement(input_type, "ip")
        ip_address = ET.SubElement(ip, "ip-address")
        ip_address.text = kwargs.pop('ip_address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_arp_output_arp_entry_ip_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_arp = ET.Element("get_arp")
        config = get_arp
        output = ET.SubElement(get_arp, "output")
        arp_entry = ET.SubElement(output, "arp-entry")
        ip_address = ET.SubElement(arp_entry, "ip-address")
        ip_address.text = kwargs.pop('ip_address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_arp_output_arp_entry_mac_address(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_arp = ET.Element("get_arp")
        config = get_arp
        output = ET.SubElement(get_arp, "output")
        arp_entry = ET.SubElement(output, "arp-entry")
        ip_address_key = ET.SubElement(arp_entry, "ip-address")
        ip_address_key.text = kwargs.pop('ip_address')
        mac_address = ET.SubElement(arp_entry, "mac-address")
        mac_address.text = kwargs.pop('mac_address')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_arp_output_arp_entry_interface_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_arp = ET.Element("get_arp")
        config = get_arp
        output = ET.SubElement(get_arp, "output")
        arp_entry = ET.SubElement(output, "arp-entry")
        ip_address_key = ET.SubElement(arp_entry, "ip-address")
        ip_address_key.text = kwargs.pop('ip_address')
        interface_type = ET.SubElement(arp_entry, "interface-type")
        interface_type.text = kwargs.pop('interface_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_arp_output_arp_entry_interface_name(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_arp = ET.Element("get_arp")
        config = get_arp
        output = ET.SubElement(get_arp, "output")
        arp_entry = ET.SubElement(output, "arp-entry")
        ip_address_key = ET.SubElement(arp_entry, "ip-address")
        ip_address_key.text = kwargs.pop('ip_address')
        interface_name = ET.SubElement(arp_entry, "interface-name")
        interface_name.text = kwargs.pop('interface_name')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_arp_output_arp_entry_is_resolved(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_arp = ET.Element("get_arp")
        config = get_arp
        output = ET.SubElement(get_arp, "output")
        arp_entry = ET.SubElement(output, "arp-entry")
        ip_address_key = ET.SubElement(arp_entry, "ip-address")
        ip_address_key.text = kwargs.pop('ip_address')
        is_resolved = ET.SubElement(arp_entry, "is-resolved")
        is_resolved.text = kwargs.pop('is_resolved')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_arp_output_arp_entry_age(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_arp = ET.Element("get_arp")
        config = get_arp
        output = ET.SubElement(get_arp, "output")
        arp_entry = ET.SubElement(output, "arp-entry")
        ip_address_key = ET.SubElement(arp_entry, "ip-address")
        ip_address_key.text = kwargs.pop('ip_address')
        age = ET.SubElement(arp_entry, "age")
        age.text = kwargs.pop('age')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        
    def get_arp_output_arp_entry_entry_type(self, **kwargs):
        """Auto Generated Code
        """
        config = ET.Element("config")
        get_arp = ET.Element("get_arp")
        config = get_arp
        output = ET.SubElement(get_arp, "output")
        arp_entry = ET.SubElement(output, "arp-entry")
        ip_address_key = ET.SubElement(arp_entry, "ip-address")
        ip_address_key.text = kwargs.pop('ip_address')
        entry_type = ET.SubElement(arp_entry, "entry-type")
        entry_type.text = kwargs.pop('entry_type')

        callback = kwargs.pop('callback', self._callback)
        return callback(config)
        


"""
Copyright 2015 Brocade Communications Systems, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import xml.etree.ElementTree as ET
from pynos.versions.ver_7.ver_7_0_0.yang.brocade_lldp_ext \
    import brocade_lldp_ext as brcd_lldp
import pynos.utilities
from pynos.versions.base.lldp import LLDP as BaseLLDP


class LLDP(BaseLLDP):
    """LLDP class containing LLDP methods and attributes.
    """
    def __init__(self, callback):
        """LLDP init method.

        Args:
            callback (function): Callback function that will be called for each
                action.

        Returns:
            LLDP Object

        Raises:
            None
        """
        super(LLDP, self).__init__(callback)
        self._lldp = brcd_lldp(callback=pynos.utilities.return_xml)

    def neighbors(self, **kwargs):

        """list[dict]: A list of dictionary items describing the operational
        state of LLDP.
        """
        urn = "{urn:brocade.com:mgmt:brocade-lldp-ext}"

        result = []
        has_more = ''
        last_ifindex = ''
        rbridge_id = None
        if 'rbridge_id' in kwargs:
            rbridge_id = kwargs.pop('rbridge_id')
        while (has_more == '') or (has_more == 'true'):
            request_lldp = self.get_lldp_neighbors_request(last_ifindex,
                                                           rbridge_id)
            lldp_result = self._callback(request_lldp, 'get')
            has_more = lldp_result.find('%shas-more' % urn).text

            for item in lldp_result.findall('%slldp-neighbor-detail' % urn):
                local_int_name = item.find('%slocal-interface-name' % urn).text
                local_int_mac = item.find('%slocal-interface-mac' % urn).text
                last_ifindex = item.find(
                    '%slocal-interface-ifindex' % urn).text
                remote_int_name = item.find(
                    '%sremote-interface-name' % urn).text
                remote_int_mac = item.find('%sremote-interface-mac' % urn).text
                remote_chas_id = item.find('%sremote-chassis-id' % urn).text
                try:
                    remote_sys_name = item.find(
                        '%sremote-system-name' % urn).text
                except AttributeError:
                    remote_sys_name = ''
                try:
                    remote_sys_desc = item.find('%sremote-system-description' %
                                                urn).text
                except AttributeError:
                    remote_sys_desc = ''
                try:
                    remote_mgmt_addr = item.find(
                        '%sremote-management-address' %
                        urn).text
                except AttributeError:
                    remote_mgmt_addr = ''
                if 'Fo ' in local_int_name:
                    local_int_name = local_int_name.replace(
                        'Fo ',
                        'FortyGigabitEthernet '
                    )
                if 'Te ' in local_int_name:
                    local_int_name = local_int_name.replace(
                        'Te ',
                        'TenGigabitEthernet '
                    )

                item_results = {'local-int-name': local_int_name,
                                'local-int-mac': local_int_mac,
                                'remote-int-name': remote_int_name,
                                'remote-int-mac': remote_int_mac,
                                'remote-chassis-id': remote_chas_id,
                                'remote-system-name': remote_sys_name,
                                'remote-system-description': remote_sys_desc,
                                'remote-management-address': remote_mgmt_addr}
                result.append(item_results)

        return result

    @staticmethod
    def get_lldp_neighbors_request(last_ifindex, rbridge_id):
        """ Creates a new Netconf request based on the last received or if
        rbridge_id is specifed
        ifindex when the hasMore flag is true
        """

        request_lldp = ET.Element(
            'get-lldp-neighbor-detail',
            xmlns="urn:brocade.com:mgmt:brocade-lldp-ext"
        )
        if rbridge_id is not None:
            rbridge_el = ET.SubElement(request_lldp, "rbridge-id")
            rbridge_el.text = rbridge_id
        elif last_ifindex != '':
            last_received_int = ET.SubElement(request_lldp,
                                              "last-rcvd-ifindex")
            last_received_int.text = last_ifindex

        return request_lldp
